@@ -261,13 +261,39 @@ class PyPi(object):
                         res.append((targetdistro, d, fname))
         return res
 
-    def get_distros(self):
+    def search(self, s, order_by='distro_id'):
         ses = self.sessionmaker()
-        distros = [x for x in ses.query(model.SQLDistro)
+        query = ses.query(model.SQLDistro)
+        expr = '%%%s%%' % s
+        query = query.filter(sa.or_(model.SQLDistro.name.like(expr),
+                                    model.SQLDistro.description.like(expr),
+                                    model.SQLDistro.summary.like(expr)))
+
+        if order_by is not None:
+            vals = []
+            for x in order_by.split(','):
+                vals.append('distros_'+x.strip())
+            query = query.order_by(','.join(vals))
+
+        distros = [x for x in query
+                   if self.has_role(x.distro_id,
+                                    READER_ROLE, MANAGER_ROLE,
+                                    model.OWNER_ROLE)]
+        return distros
+
+    def get_distros(self, order_by=None):
+        ses = self.sessionmaker()
+        query = ses.query(model.SQLDistro)
+        if order_by is not None:
+            vals = []
+            for x in order_by.split(','):
+                vals.append('distros_'+x.strip())
+            query = query.order_by(','.join(vals))
+
+        distros = [x for x in query
                    if self.has_role(x.distro_id,
                                     READER_ROLE, MANAGER_ROLE,
                                     model.OWNER_ROLE)]
-        distros.sort(lambda x, y: cmp(x.name, y.name))
         return distros
 
     def get_distro(self, distro_id=None, distro_name=None):
